PhysicalPosition

Struct PhysicalPosition 

pub struct PhysicalPosition {
    pub x: f64,
    pub y: f64,
}
A position represented in physical pixels.

The position is stored as floats, so please be careful. Casting floats to integers truncates the fractional part, which can cause noticable issues. To help with that, an Into<(i32, i32)> implementation is provided which does the rounding for you.

Fields

x: f64y: f64

Implementations

Source

impl PhysicalPosition

pub fn new(x: f64, y: f64) -> Self

pub fn from_logical<T: Into<LogicalPosition>>( logical: T, dpi_factor: f64, ) -> Self

pub fn to_logical(&self, dpi_factor: f64) -> LogicalPosition